@@ -2,7 +2,7 @@
  *
  * flickcurl.h - Flickcurl API
  *
- * Copyright (C) 2007-2009, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2007-2012, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -174,6 +174,9 @@ typedef enum {
  * @PHOTO_FIELD_original_width: original photo width
  * @PHOTO_FIELD_original_height: original photo height
  * @PHOTO_FIELD_views: number of photo views
+ * @PHOTO_FIELD_comments: number of photo comments
+ * @PHOTO_FIELD_favorites: number of photo favorites
+ * @PHOTO_FIELD_gallery_comment: comment on the photo when used in a gallery
  * @PHOTO_FIELD_none: internal
  * @PHOTO_FIELD_FIRST: internal offset to first in enum list
  * @PHOTO_FIELD_LAST: internal offset to last in enum list
@@ -241,8 +244,11 @@ typedef enum {
   PHOTO_FIELD_original_width,
   PHOTO_FIELD_original_height,
   PHOTO_FIELD_views,
+  PHOTO_FIELD_comments,
+  PHOTO_FIELD_favorites,
+  PHOTO_FIELD_gallery_comment,
   PHOTO_FIELD_FIRST = PHOTO_FIELD_dateuploaded,
-  PHOTO_FIELD_LAST = PHOTO_FIELD_views
+  PHOTO_FIELD_LAST = PHOTO_FIELD_gallery_comment
 } flickcurl_photo_field_type;
 
 
@@ -519,6 +525,33 @@ typedef struct {
 } flickcurl_location;
   
 
+/**
+ * flickcurl_note: 
+ * @id: note identifier (per-photo)
+ * @author: author (may be NULL)
+ * @authorname: author real name (may be NULL)
+ * @x: The left coordinate of the note
+ * @y: The top coordinate of the note
+ * @w: The width of the note
+ * @h: The height of the note
+ * @text: The description of the note
+ *
+ * A note attached to a rectangular area on a photo.
+ *
+ * A Photo Note.
+ */
+typedef struct flickcurl_note_s {
+  int id;
+  char* author;
+  char* authorname;
+  unsigned int x;
+  unsigned int y;
+  unsigned int w;
+  unsigned int h;
+  char* text;
+} flickcurl_note;
+
+
 /**
  * flickcurl_place_type:
  * @FLICKCURL_PLACE_LOCATION: a general location
@@ -736,6 +769,8 @@ typedef struct {
  * @place: place
  * @video: video (may be NULL)
  * @media_type: "photo" or "video"
+ * @notes: array of notes (may be NULL)
+ * @notes_count: size of notes array
  *
  * A photo or video.
  *
@@ -754,6 +789,9 @@ typedef struct flickcurl_photo_s {
   flickcurl_video* video;
 
   char *media_type;
+
+  flickcurl_note** notes;
+  int notes_count;
 } flickcurl_photo;
 
 
@@ -957,6 +995,40 @@ struct flickcurl_category_s {
 typedef struct flickcurl_category_s flickcurl_category;
 
 
+/**
+ * flickcurl_gallery: 
+ * @id: gallery ID
+ * @url: URL of gallery
+ * @owner: owner NSID
+ * @date_create: creation date of gallery
+ * @date_update: update / last modified date of gallery
+ * @primary_photo: primary photo for the gallery
+ * @count_photos: number of photos in the gallery
+ * @count_videos: number of photos in the gallery
+ * @title: Gallery title
+ * @description: Gallery description
+ *
+ * A photo gallery.
+ *
+ * The list of photos in the gallery is available via the API calls
+ * flickcurl_galleries_getPhotos() or
+ * flickcurl_galleries_getPhotos_params()
+ *
+ */
+typedef struct {
+  char *id;
+  char *url;
+  char *owner;
+  int date_create;
+  int date_update;
+  flickcurl_photo* primary_photo;
+  int count_photos;
+  int count_videos;
+  char *title;
+  char *description;
+} flickcurl_gallery;
+
+
 /**
  * flickcurl_photoset:
  * @id: photoset ID
@@ -968,6 +1040,7 @@ typedef struct flickcurl_category_s flickcurl_category;
  * @title: title of photoset
  * @description: description of photoset (may be NULL)
  * @photos: photos in a photoset (may be NULL)
+ * @owner: owner NSID
  *
  * A photoset.
  *
@@ -982,6 +1055,7 @@ typedef struct {
   char* title;
   char *description;
   struct flickcurl_photo_s** photos;
+  char *owner; 
 } flickcurl_photoset;
 
 
@@ -1108,6 +1182,9 @@ typedef struct {
  * @photos_count: number of photos in @photos array if @format is NULL. Undefined on failure
  * @content: raw content if @format is not NULL.  Also may be NULL on failure.
  * @content_length: size of @content if @format is not NULL. Undefined on failure
+ * @page: current photo list page
+ * @per_page: current photo list per-page
+ * @total_count: total number of photos available of which the current @page and @per_page is a slice
  *
  * Photos List result.
  */
@@ -1117,6 +1194,9 @@ typedef struct {
   int photos_count;
   char* content;
   size_t content_length;
+  int page;
+  int per_page;
+  int total_count;
 } flickcurl_photos_list;
 
 
@@ -1158,6 +1238,7 @@ typedef struct {
  * @is_family: is family photo boolean (non-0 true)
  * @safety_level: 1=safe, 2=moderate, 3=restricted
  * @content_type: 1=photo, 2=screenshot, 3=other/artwork
+ * @hidden: 1=in global search, 2=hidden from publish searches (Flickcurl 1.22+)
  *
  * Photo upload parameters
  */
@@ -1171,6 +1252,8 @@ typedef struct {
   int is_family;  
   int safety_level;
   int content_type;
+  /* Flickcurl 1.22+ */
+  int hidden;
 } flickcurl_upload_params;
 
 
@@ -1226,6 +1309,7 @@ typedef struct {
  * @woe_id: A 32-bit identifier that uniquely represents spatial entities. (not used if bbox argument is present).  Same restrictions as @place_id (or 0)
  * @geo_context: A numeric value representing the photo's geotagginess beyond latitude and longitude. The current list of context IDs is 0: not defined, 1: indoors and 2: outdoors.  Geo queries require some sort of limiting agent in order to prevent the database from crying (or 0)
  * @is_commons: Limit the scope of the search to only photos that are part of the Flickr Commons project. Default is false (or 0)
+ * @in_gallery: Limit the scope of the search to only photos that are in a gallery. Default is false, search all photos.
  *
  * Search parameters for flickcurl_photos_search()
  */
@@ -1262,8 +1346,49 @@ typedef struct {
   int woe_id;
   int geo_context;
   int is_commons;
+  int in_gallery;
 } flickcurl_search_params;
-  
+
+
+/**
+ * flickcurl_stat:
+ * @views: number of views of item
+ * @comments: number of comments on item
+ * @favorites: number of item favorites
+ * @name: name assocated with stat (e.g. domain name)
+ * @url: URL associated with stat (e.g. referrer URL)
+ * @searchterms: search term assocated with stat
+ *
+ * Statistics object
+ */
+typedef struct {
+  int views;
+  int comments;
+  int favorites;
+  char *name;
+  char *url;
+  char *searchterms;
+} flickcurl_stat;
+
+
+/**
+ * flickcurl_view_stats
+ * @total: total view
+ * @photos: number of photo views
+ * @photostreams: number of photostream views
+ * @sets: number of set views
+ * @collections: number of collection views
+ *
+ * Total views statistics
+ */
+typedef struct {
+  int total;
+  int photos;
+  int photostreams;
+  int sets;
+  int collections;
+} flickcurl_view_stats;
+
 
 /**
  * flickcurl_size:
@@ -1276,6 +1401,22 @@ typedef struct {
  *
  * A photo at a size.
  *
+ * Supported sizes and their letter suffixes used in the @source and
+ * the @url fields are as follows:
+ *
+ * s: small square 75x75.
+ * q: large square 150x150 (2011-03-12 or later).
+ * t: thumbnail, 100 on longest side.
+ * m: small, 240 on longest side.
+ * n: small, 320 on longest side (2011-03-12 or later).
+ * -: medium, 500 on longest side.
+ * z: medium 640, 640 on longest side.
+ * b: large, 1024 on longest side*.
+ * o: original image, either a jpg, gif or png, depending on source format.
+ *
+ * The 'q' and 'n' sizes were announced 2011-03-12 in
+ * http://tech.groups.yahoo.com/group/yws-flickr/message/7483
+ *
  */
 typedef struct {
   char *label;
@@ -1355,7 +1496,9 @@ struct flickcurl_serializer_s;
  *
  * Triple part types
  *
- * These are the same as raptor_identifier_type values.
+ * These are the same enumeration values as used by Raptor V2
+ * raptor_term_type enumeration and Raptor V1 raptor_identifier_type
+ * enumeration.
  */
 typedef enum {
   FLICKCURL_TERM_TYPE_RESOURCE = 1,
@@ -1418,7 +1561,7 @@ typedef struct {
 /* callback handlers */
 
 /**
- * flickcurl_message_handler
+ * flickcurl_message_handler:
  * @user_data: user data pointer
  * @message: error message
  *
@@ -1426,8 +1569,9 @@ typedef struct {
  */
 typedef void (*flickcurl_message_handler)(void *user_data, const char *message);
 
+
 /**
- * flickcurl_tag_handler
+ * flickcurl_tag_handler:
  * @user_data: user data pointer
  * @tag: tag
  *
@@ -1436,6 +1580,28 @@ typedef void (*flickcurl_message_handler)(void *user_data, const char *message);
 typedef void (*flickcurl_tag_handler)(void *user_data, flickcurl_tag* tag);
 
 
+/**
+ * flickcurl_curl_setopt_handler:
+ * @user_data: user data pointer
+ * @curl_handle: curl CURL* handle
+ *
+ * Flickcurl curl options handle callback.
+ *
+ * For use with flickcurl_set_curl_setopt_handler() to set curl
+ * handle options once Flickcurl has created the CURL* handle
+ * internally.
+ *
+ * NOTE: The type of @curl_handle is void* so that curl headers are
+ * optional when compiling against flickcurl.
+ *
+ * WARNING: This callback is called with two void args in the order
+ * curl handler user data, curl handle (CURL* pointer) - take care in
+ * getting them correct in implementation.
+ *
+ */
+typedef void (*flickcurl_curl_setopt_handler)(void *user_data, void *curl_handle);
+
+
 /* library constants */
 FLICKCURL_API
 extern const char* const flickcurl_short_copyright_string;
@@ -1454,6 +1620,12 @@ FLICKCURL_API
 extern const char* const flickcurl_flickr_upload_service_uri;
 FLICKCURL_API
 extern const char* const flickcurl_flickr_replace_service_uri;
+FLICKCURL_API
+extern const char* const flickcurl_flickr_oauth_request_token_uri;
+FLICKCURL_API
+extern const char* const flickcurl_flickr_oauth_authorize_uri;
+FLICKCURL_API
+extern const char* const flickcurl_flickr_oauth_access_token_uri;
 
 
 /* library init - call once before creating anything */
@@ -1467,6 +1639,8 @@ void flickcurl_finish(void);
 /* flickcurl* object constructor */
 FLICKCURL_API
 flickcurl* flickcurl_new(void);
+FLICKCURL_API
+flickcurl* flickcurl_new_with_handle(void* curl_handle);
 
 /* flickcurl* object destructor */
 FLICKCURL_API
@@ -1474,6 +1648,8 @@ void flickcurl_free(flickcurl *fc);
 
 /* flickcurl* object set methods */
 FLICKCURL_API
+void flickcurl_set_curl_setopt_handler(flickcurl *fc, flickcurl_curl_setopt_handler curl_handler, void* curl_handler_data);
+FLICKCURL_API
 void flickcurl_set_service_uri(flickcurl *fc, const char *uri);
 FLICKCURL_API
 void flickcurl_set_upload_service_uri(flickcurl *fc, const char *uri);
@@ -1522,12 +1698,16 @@ void flickcurl_free_collection(flickcurl_collection *collection);
 FLICKCURL_API
 void flickcurl_free_collections(flickcurl_collection** collections);
 FLICKCURL_API
+void flickcurl_free_gallery(flickcurl_gallery *gallery);
+FLICKCURL_API
 void flickcurl_free_tag_namespace(flickcurl_tag_namespace *tag_nspace);
 FLICKCURL_API
 void flickcurl_free_tag_namespaces(flickcurl_tag_namespace** tag_nspaces);
 FLICKCURL_API
 void flickcurl_free_tag(flickcurl_tag *t);
 FLICKCURL_API
+void flickcurl_free_tags(flickcurl_tag **tags);
+FLICKCURL_API
 void flickcurl_free_tag_clusters(flickcurl_tag_clusters *tcs);
 FLICKCURL_API
 void flickcurl_free_photo(flickcurl_photo *photo);
@@ -1624,6 +1804,10 @@ const char* flickcurl_get_safety_level_label(int safety_level);
 FLICKCURL_API
 int flickcurl_get_safety_level_from_string(const char* safety_level_string);
 FLICKCURL_API
+const char* flickcurl_get_hidden_label(int hidden);
+FLICKCURL_API
+int flickcurl_get_hidden_from_string(const char* hidden_string);
+FLICKCURL_API
 int flickcurl_get_feed_format_info(int feed_format, const char** name_p, const char** label_p, const char** mime_type_p);
 FLICKCURL_API
 int flickcurl_get_extras_format_info(int extras_format, const char** name_p, const char** label_p);
@@ -1642,10 +1826,14 @@ int flickcurl_search_params_init(flickcurl_search_params* params);
  * Handler to get variables returned from an 'INI' style configuration file
 */
 typedef void (*set_config_var_handler)(void* userdata, const char* key, const char* value);
+FLICKCURL_API FLICKCURL_DEPRECATED
+int read_ini_config(const char* filename, const char* section, void* user_data, set_config_var_handler handler);
 FLICKCURL_API
-int read_ini_config(const char* filename, const char* application, void* user_data, set_config_var_handler handler);
-
-
+int flickcurl_config_read_ini(flickcurl* fc, const char* filename, const char* section, void* user_data, set_config_var_handler handler);
+FLICKCURL_API
+void flickcurl_config_var_handler(void* userdata, const char* key, const char* value);
+FLICKCURL_API
+int flickcurl_config_write_ini(flickcurl *fc, const char* filename, const char* section);
 
 /* Flickr API calls */
 
@@ -1666,6 +1854,40 @@ FLICKCURL_API
 char* flickcurl_auth_getFullToken(flickcurl* fc, const char* frob);
 FLICKCURL_API
 char* flickcurl_auth_getToken(flickcurl* fc, const char* frob);
+FLICKCURL_API
+int flickcurl_auth_oauth_getAccessToken(flickcurl* fc);
+FLICKCURL_API
+const char* flickcurl_get_oauth_token(flickcurl *fc);
+FLICKCURL_API
+void flickcurl_set_oauth_token(flickcurl *fc, const char* token);
+FLICKCURL_API
+const char* flickcurl_get_oauth_token_secret(flickcurl* fc);
+FLICKCURL_API
+void flickcurl_set_oauth_token_secret(flickcurl* fc, const char *secret);
+FLICKCURL_API
+const char* flickcurl_get_oauth_client_key(flickcurl *fc);
+FLICKCURL_API
+const char* flickcurl_get_oauth_client_secret(flickcurl *fc);
+FLICKCURL_API
+void flickcurl_set_oauth_client_key(flickcurl *fc, const char* client_key);
+FLICKCURL_API
+void flickcurl_set_oauth_client_secret(flickcurl *fc, const char* client_secret);
+FLICKCURL_API
+const char* flickcurl_get_oauth_request_token(flickcurl* fc);
+FLICKCURL_API
+const char* flickcurl_get_oauth_request_token_secret(flickcurl* fc);
+FLICKCURL_API
+void flickcurl_set_oauth_request_token(flickcurl *fc, const char* token);
+FLICKCURL_API
+void flickcurl_set_oauth_request_token_secret(flickcurl *fc, const char* secret);
+
+/* OAuth flow requests */
+FLICKCURL_API
+int flickcurl_oauth_create_request_token(flickcurl* fc, const char* callback);
+FLICKCURL_API
+char* flickcurl_oauth_get_authorize_uri(flickcurl* fc);
+FLICKCURL_API
+int flickcurl_oauth_create_access_token(flickcurl* fc, const char* verifier);
 
 /* flickr.blogs */
 FLICKCURL_API
@@ -1695,6 +1917,8 @@ const char* flickcurl_get_institution_url_type_label(flickcurl_institution_url_t
 FLICKCURL_API
 int flickcurl_favorites_add(flickcurl* fc, const char* photo_id);
 FLICKCURL_API
+flickcurl_photos_list** flickcurl_favorites_getContext(flickcurl* fc, const char* photo_id, const char* user_id, int num_prev, int num_next, const char* extras);
+FLICKCURL_API
 flickcurl_photo** flickcurl_favorites_getList(flickcurl* fc, const char* user_id, const char* extras, int per_page, int page);
 FLICKCURL_API
 flickcurl_photos_list* flickcurl_favorites_getList_params(flickcurl* fc, const char* user_id, flickcurl_photos_list_params* list_params);
@@ -1705,6 +1929,30 @@ flickcurl_photos_list* flickcurl_favorites_getPublicList_params(flickcurl* fc, c
 FLICKCURL_API
 int flickcurl_favorites_remove(flickcurl* fc, const char* photo_id);
 
+/* flickr.galleries */
+FLICKCURL_API
+int flickcurl_galleries_addPhoto(flickcurl* fc, const char* gallery_id, const char* photo_id, const char* comment_text);
+FLICKCURL_API
+char* flickcurl_galleries_create(flickcurl* fc, const char* title, const char* description, const char* primary_photo_id, char** gallery_url_p);
+FLICKCURL_API
+int flickcurl_galleries_editMeta(flickcurl* fc, const char* gallery_id, const char* title, const char* description);
+FLICKCURL_API
+int flickcurl_galleries_editPhoto(flickcurl* fc, const char* gallery_id, const char* photo_id, const char* new_comment);
+FLICKCURL_API
+int flickcurl_galleries_editPhotos(flickcurl* fc, const char* gallery_id, const char* primary_photo_id, const char** photo_ids_array);
+FLICKCURL_API
+flickcurl_gallery* flickcurl_galleries_getInfo(flickcurl* fc, const char* gallery_id);
+FLICKCURL_API
+flickcurl_gallery** flickcurl_galleries_getList(flickcurl* fc, const char* user_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_gallery** flickcurl_galleries_getListForPhoto(flickcurl* fc, const char* photo_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_photos_list* flickcurl_galleries_getPhotos_params(flickcurl* fc, const char* gallery_id, flickcurl_photos_list_params* list_params);
+FLICKCURL_API
+flickcurl_photo** flickcurl_galleries_getPhotos(flickcurl* fc, const char* gallery_id, const char* extras, int per_page, int page);
+FLICKCURL_API
+void flickcurl_free_galleries(flickcurl_gallery **galleries_object);
+
 /* flickr.groups */
 FLICKCURL_API
 void flickcurl_free_category(flickcurl_category *category);
@@ -1782,6 +2030,14 @@ char* flickcurl_people_findByUsername(flickcurl* fc, const char* username);
 FLICKCURL_API
 flickcurl_person* flickcurl_people_getInfo(flickcurl* fc, const char* user_id);
 FLICKCURL_API
+flickcurl_photos_list* flickcurl_people_getPhotos_params(flickcurl* fc, const char* user_id, int safe_search, const char* min_upload_date, const char* max_upload_date, const char* min_taken_date, const char* max_taken_date, int content_type, int privacy_filter, flickcurl_photos_list_params* list_params);
+FLICKCURL_API
+flickcurl_photo** flickcurl_people_getPhotos(flickcurl* fc, const char* user_id, int safe_search, const char* min_upload_date, const char* max_upload_date, const char* min_taken_date, const char* max_taken_date, int content_type, int privacy_filter, const char* extras, int per_page, int page);
+FLICKCURL_API
+flickcurl_photos_list* flickcurl_people_getPhotosOf_params(flickcurl* fc, const char* user_id, flickcurl_photos_list_params* list_params);
+FLICKCURL_API
+flickcurl_photo** flickcurl_people_getPhotosOf(flickcurl* fc, const char* user_id, const char* extras, int per_page, int page);
+FLICKCURL_API
 flickcurl_group** flickcurl_people_getPublicGroups(flickcurl* fc, const char* user_id);
 FLICKCURL_API
 flickcurl_photo** flickcurl_people_getPublicPhotos(flickcurl* fc, const char* user_id,  const char* extras, int per_page, int page);
@@ -1862,6 +2118,19 @@ int flickcurl_photos_setSafetyLevel(flickcurl* fc, const char* photo_id, int saf
 FLICKCURL_API
 int flickcurl_photos_setTags(flickcurl* fc, const char* photo_id, const char* tags);
 
+/* flickr.photos.people */
+FLICKCURL_API
+int flickcurl_photos_people_add(flickcurl* fc, const char* photo_id, const char* user_id, int person_x, int person_y, int person_w, int person_h);
+FLICKCURL_API
+int flickcurl_photos_people_delete(flickcurl* fc, const char* photo_id, const char* user_id);
+FLICKCURL_API
+int flickcurl_photos_people_deleteCoords(flickcurl* fc, const char* photo_id, const char* user_id);
+FLICKCURL_API
+int flickcurl_photos_people_editCoords(flickcurl* fc, const char* photo_id, const char* user_id, int person_x, int person_y, int person_w, int person_h);
+FLICKCURL_API
+flickcurl_person** flickcurl_photos_people_getList(flickcurl* fc, const char* photo_id);
+
+
 /* flickr.places */
 FLICKCURL_API
 flickcurl_place** flickcurl_places_find(flickcurl* fc, const char* query);
@@ -2007,6 +2276,12 @@ FLICKCURL_API
 int flickcurl_photosets_orderSets(flickcurl* fc, const char** photoset_ids_array);
 FLICKCURL_API
 int flickcurl_photosets_removePhoto(flickcurl* fc, const char* photoset_id, const char* photo_id);
+FLICKCURL_API
+int flickcurl_photosets_removePhotos(flickcurl* fc, const char* photoset_id, const char** photo_ids_array);
+FLICKCURL_API
+int flickcurl_photosets_reorderPhotos(flickcurl* fc, const char* photoset_id, const char** photo_ids_array);
+FLICKCURL_API
+int flickcurl_photosets_setPrimaryPhoto(flickcurl* fc, const char* photoset_id, const char* photo_id);
 
 /* flickr.photosets.comments */
 FLICKCURL_API
@@ -2038,6 +2313,45 @@ char** flickcurl_reflection_getMethods(flickcurl* fc);
 FLICKCURL_API
 flickcurl_method* flickcurl_reflection_getMethodInfo(flickcurl* fc, const char* name);
 
+/* flickr.stats */
+FLICKCURL_API
+int flickcurl_stats_getCSVFiles(flickcurl* fc);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getCollectionDomains(flickcurl* fc, const char* date, const char* collection_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getCollectionReferrers(flickcurl* fc, const char* date, const char* domain, const char* collection_id, int per_page, int page);
+FLICKCURL_API
+int flickcurl_stats_getCollectionStats(flickcurl* fc, const char* date, const char* collection_id);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotoDomains(flickcurl* fc, const char* date, const char* photo_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotoReferrers(flickcurl* fc, const char* date, const char* domain, const char* photo_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat* flickcurl_stats_getPhotoStats(flickcurl* fc, const char* date, const char* photo_id);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotosetDomains(flickcurl* fc, const char* date, const char* photoset_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotosetReferrers(flickcurl* fc, const char* date, const char* domain, const char* photoset_id, int per_page, int page);
+FLICKCURL_API
+int flickcurl_stats_getPhotosetStats(flickcurl* fc, const char* date, const char* photoset_id);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotostreamDomains(flickcurl* fc, const char* date, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotostreamReferrers(flickcurl* fc, const char* date, const char* domain, int per_page, int page);
+FLICKCURL_API
+int flickcurl_stats_getPhotostreamStats(flickcurl* fc, const char* date);
+FLICKCURL_API
+flickcurl_photo** flickcurl_stats_getPopularPhotos(flickcurl* fc, const char* date, const char* sort, int per_page, int page, const char* extras);
+FLICKCURL_API
+flickcurl_view_stats* flickcurl_stats_getTotalViews(flickcurl* fc, const char* date);
+
+FLICKCURL_API
+void flickcurl_free_stat(flickcurl_stat *stat);
+FLICKCURL_API
+void flickcurl_free_stats(flickcurl_stat **stats_object);
+FLICKCURL_API
+void flickcurl_free_view_stats(flickcurl_view_stats *view_stats);
+
 /* flickr.tag */
 FLICKCURL_API
 flickcurl_photos_list* flickcurl_tags_getClusterPhotos(flickcurl* fc, const char* tag, const char* cluster_id, flickcurl_photos_list_params* list_params);
@@ -2072,6 +2386,8 @@ char* flickcurl_urls_getUserPhotos(flickcurl* fc, const char* user_id);
 FLICKCURL_API
 char* flickcurl_urls_getUserProfile(flickcurl* fc, const char* user_id);
 FLICKCURL_API
+char* flickcurl_urls_lookupGallery(flickcurl* fc, const char* url);
+FLICKCURL_API
 char* flickcurl_urls_lookupGroup(flickcurl* fc, const char* url);
 FLICKCURL_API
 char* flickcurl_urls_lookupUser(flickcurl* fc, const char* url);
